summaryrefslogtreecommitdiffstats
path: root/akregator/src/akregator_view.h
diff options
context:
space:
mode:
Diffstat (limited to 'akregator/src/akregator_view.h')
-rw-r--r--akregator/src/akregator_view.h25
1 files changed, 13 insertions, 12 deletions
diff --git a/akregator/src/akregator_view.h b/akregator/src/akregator_view.h
index 4b9dcd13..66796d42 100644
--- a/akregator/src/akregator_view.h
+++ b/akregator/src/akregator_view.h
@@ -20,8 +20,8 @@
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
As a special exception, permission is given to link this program
- with any edition of Qt, and distribute the resulting executable,
- without including the source code for Qt in the source distribution.
+ with any edition of TQt, and distribute the resulting executable,
+ without including the source code for TQt in the source distribution.
*/
#ifndef _AKREGATORVIEW_H_
@@ -77,18 +77,19 @@ namespace Akregator {
/**
* This is the main widget of the view, containing tree view, article list, viewer etc.
*/
- class View : public QWidget
+ class View : public TQWidget
{
Q_OBJECT
+ TQ_OBJECT
public:
/** constructor
- @param part the Akregator::Part which tqcontains this widget
- @param parent parent widget
+ @param part the Akregator::Part which contains this widget
+ @param tqparent tqparent widget
@param Actionmanager for this view
@param name the name of the widget (@ref TQWidget )
*/
- View(Akregator::Part *part, TQWidget *parent, ActionManagerImpl* actionManager, const char* name);
+ View(Akregator::Part *part, TQWidget *tqparent, ActionManagerImpl* actionManager, const char* name);
/** destructor. Note that cleanups should be done in
slotOnShutdown(), so we don't risk accessing self-deleting objects after deletion. */
@@ -103,11 +104,11 @@ namespace Akregator {
@param doc the DOM tree (OPML) of the feeds to import */
bool importFeeds(const TQDomDocument& doc);
- /** Parse OPML presentation of feeds and read in articles archive, if present. If @c parent is @c NULL, the current
- feed list is tqreplaced by the parsed one
+ /** Parse OPML presentation of feeds and read in articles archive, if present. If @c tqparent is @c NULL, the current
+ feed list is replaced by the parsed one
@param doc TQDomDocument generated from OPML
- @param parent The parent group the new nodes */
- bool loadFeeds(const TQDomDocument& doc, Folder* parent = 0);
+ @param tqparent The tqparent group the new nodes */
+ bool loadFeeds(const TQDomDocument& doc, Folder* tqparent = 0);
/**
@return the displayed Feed List in OPML format
@@ -189,7 +190,7 @@ namespace Akregator {
void slotCaptionChanged(const TQString &);
/** called when URLs are dropped into the tree view */
- void slotFeedURLDropped (KURL::List &urls, TreeNode* after, Folder *parent);
+ void slotFeedURLDropped (KURL::List &urls, TreeNode* after, Folder *tqparent);
/** displays a URL in the status bar when the user moves the mouse over a link */
void slotMouseOverInfo(const KFileItem *kifi);
@@ -271,7 +272,7 @@ namespace Akregator {
protected:
- void addFeed(const TQString& url, TreeNode* after, Folder* parent, bool autoExec = true);
+ void addFeed(const TQString& url, TreeNode* after, Folder* tqparent, bool autoExec = true);
void connectToFeedList(FeedList* feedList);
void disconnectFromFeedList(FeedList* feedList);